@@ -1,5 +1,5 @@
 # -*- test-case-name: twisted.test.test_internet -*-
-# Copyright (c) 2001-2010 Twisted Matrix Laboratories.
+# Copyright (c) Twisted Matrix Laboratories.
 # See LICENSE for details.
 
 """
@@ -364,7 +364,7 @@ class _ThreePhaseEvent(object):
         """
         try:
             phase, callable, args, kwargs = handle
-        except (TypeError, ValueError), e:
+        except (TypeError, ValueError):
             raise ValueError("invalid trigger handle")
         else:
             if phase not in ('before', 'during', 'after'):
@@ -471,6 +471,7 @@ class ReactorBase(object):
         self.running = False
         self._started = False
         self._justStopped = False
+        self._startedBefore = False
         # reactor internal readers, e.g. the waker.
         self._internalReaders = set()
         self.waker = None
@@ -570,6 +571,7 @@ class ReactorBase(object):
                 "Can't stop reactor that isn't running.")
         self._stopped = True
         self._justStopped = True
+        self._startedBefore = True
 
 
     def crash(self):
@@ -668,6 +670,8 @@ class ReactorBase(object):
         """
         if self._started:
             raise error.ReactorAlreadyRunning()
+        if self._startedBefore:
+            raise error.ReactorNotRestartable()
         self._started = True
         self._stopped = False
         threadable.registerAsIOThread()
@@ -721,13 +725,6 @@ class ReactorBase(object):
     def _cancelCallLater(self, tple):
         self._cancellations+=1
 
-    def cancelCallLater(self, callID):
-        """See twisted.internet.interfaces.IReactorTime.cancelCallLater.
-        """
-        # DO NOT DELETE THIS - this is documented in Python in a Nutshell, so we
-        # we can't get rid of it for a long time.
-        warnings.warn("reactor.cancelCallLater(callID) is deprecated - use callID.cancel() instead")
-        callID.cancel()
 
     def getDelayedCalls(self):
         """Return all the outstanding delayed calls in the system.
