@@ -1,5 +1,5 @@
 # -*- test-case-name: twisted.test.test_pb -*-
-# Copyright (c) 2001-2008 Twisted Matrix Laboratories.
+# Copyright (c) Twisted Matrix Laboratories.
 # See LICENSE for details.
 
 """
@@ -124,7 +124,7 @@ class Referenceable(Serializable):
         serialize this to a peer.
         """
 
-        return "remote", jellier.invoker.registerReference(self)
+        return ["remote", jellier.invoker.registerReference(self)]
 
 
 class Root(Referenceable):
